@@ -242,7 +242,7 @@ void isoburn_version(int *major, int *minor, int *micro);
 */
 #define isoburn_libisofs_req_major  1
 #define isoburn_libisofs_req_minor  2
-#define isoburn_libisofs_req_micro  0 
+#define isoburn_libisofs_req_micro  2 
 
 /** The minimum version of libburn to be used with this version of libisoburn
     at compile time.
@@ -305,7 +305,7 @@ int isoburn_libburn_req(int *major, int *minor, int *micro);
 */
 #define isoburn_header_version_major  1
 #define isoburn_header_version_minor  2
-#define isoburn_header_version_micro  0
+#define isoburn_header_version_micro  2
 /** Note:
     Above version numbers are also recorded in configure.ac because libtool
     wants them as parameters at build time.
@@ -389,7 +389,7 @@ int isoburn_set_msgs_submit(int (*msgs_submit)(void *handle, int error_code,
                                void *submit_handle, int submit_flag, int flag);
 
 
-/** Aquire a target drive by its filesystem path resp. libburn persistent
+/** Acquire a target drive by its filesystem path resp. libburn persistent
     address.
     Wrapper for: burn_drive_scan_and_grab()
     @since 0.1.0
@@ -407,7 +407,7 @@ int isoburn_drive_scan_and_grab(struct burn_drive_info *drive_infos[],
                                 char* adr, int load);
 
 
-/** Aquire a target drive by its filesystem path resp. libburn persistent
+/** Acquire a target drive by its filesystem path resp. libburn persistent
     address. This is a modern successor of isoburn_drive_scan_and_grab().  
     Wrapper for: burn_drive_scan_and_grab()
     @since 0.1.2
@@ -433,15 +433,17 @@ int isoburn_drive_scan_and_grab(struct burn_drive_info *drive_infos[],
                   bit6= ignore POSIX Extended Attributes from external
                         filesystems
                   bit7= pretend read-only profile and scan for table of content
-                  bit8= re-assess already aquired (*drive_infos)[0] rather
+                  bit8= re-assess already acquired (*drive_infos)[0] rather
                         than aquiring adr
                         @since 1.1.8
     @return       1 = success , 0 = drive not found , <0 = other error
+
+    Please excuse the typo "aquire" in the function name.
 */
 int isoburn_drive_aquire(struct burn_drive_info *drive_infos[],
                          char* adr, int flag);
 
-/** Aquire a drive from the burn_drive_info[] array which was obtained by
+/** Acquire a drive from the burn_drive_info[] array which was obtained by
     a previous call of burn_drive_scan(). 
     Wrapper for: burn_drive_grab()
     @since 0.1.0
@@ -757,6 +759,56 @@ int isoburn_ropt_new(struct isoburn_read_opts **o, int flag);
 */
 int isoburn_ropt_destroy(struct isoburn_read_opts **o, int flag);
 
+/** Sets the size and granularity of the cache which libisoburn provides to
+    libisofs for reading of ISO image data. This cache consists of several
+    tiles which are buffers of a given size. The ISO image is divided into
+    virtual tiles of that size. A cache tile may hold an in-memory copy
+    of such a virtual image tile.
+    When libisofs requests to read a block, then first the cache is inquired
+    whether it holds that block. If not, then the block is read via libburn
+    together with its neighbors in their virtual image tile into a free
+    cache tile. If no cache tile is free, then the one will be re-used which
+    has the longest time of not being hit by a read attempt.
+
+    A larger cache might speed up image loading by reducing the number of
+    libburn read calls on the directory tree. It might also help with
+    reading the content of many small files, if for some reason it is not an
+    option to sort access by LBA.
+    Caching will not provide much benefit with libburn "stdio:" drives,
+    because the operating system is supposed to provide the same speed-up
+    in a more flexible way.
+
+    @since 1.2.2
+    @param o            The option set to work on.
+                        It is permissible to submit NULL in order to just
+                        have the parameters tested.
+    @param cache_tiles  Number of tiles in the cache. Not less than 1.
+                        Default is 32.
+    @param tile_blocks  Number of blocks per tile. Must be a power of 2.
+                        Default is 32.
+                        cache_tiles * tile_blocks * 2048 must not exceed
+                        1073741824 (= 1 GiB).
+    @param flag         Bitfield for control purposes. Unused yet. Submit 0.
+    @return             <=0 error , >0 ok
+*/ 
+int isoburn_ropt_set_data_cache(struct isoburn_read_opts *o,
+                                int cache_tiles, int tile_blocks, int flag);
+
+/** Inquire the current settings of isoburn_set_data_cache().
+    @since 1.2.2
+    @param o            The option set to work on.
+                        NULL has the same effect as flag bit0.
+    @param cache_tiles  Will return the number of tiles in the cache.
+    @param tile_blocks  Will return the number of blocks per tile.
+    @param set_flag     Will return control bits. None are defined yet.
+    @param flag         Bitfield for control purposes
+                        bit0= return default values rather than current ones
+    @return             <=0 error , >0 reply is valid
+*/
+int isoburn_ropt_get_data_cache(struct isoburn_read_opts *o,
+                                int *cache_tiles, int *tile_blocks,
+                                int *set_flag, int flag);
+
 
 /** Which existing ISO 9660 extensions in the image to read or not to read.
     Whether to read the content of an existing image at all.
@@ -1106,7 +1158,7 @@ int isoburn_igopt_get_extensions(struct isoburn_imgen_opts *o, int *ext);
                  a few other characters are allowed.
            bit6= allow_full_ascii
                  Allow all ASCII characters to be appear on an ISO-9660
-                 filename. Note * that "/" and "\0" characters are never
+                 filename. Note that "/" and "\0" characters are never
                  allowed, even in RR names.
            bit7= joliet_longer_paths
                  Allow paths in the Joliet tree to have more than
@@ -1161,6 +1213,11 @@ int isoburn_igopt_get_extensions(struct isoburn_imgen_opts *o, int *ext);
           bit17= iso1999_rec_mtime
                  Like dir_rec_mtime, but for the ISO 9660:1999 tree.
                  @since 1.2.0
+          bit18= allow_7bit_ascii
+                 Like allow_full_ascii, but only allowing 7-bit characters.
+                 Lowercase letters get mapped to uppercase if not
+                 allow_lowercase is set.
+                 Gets overridden if allow_full_ascii is enabled.
     @return 1 success, <=0 failure
 */
 #define isoburn_igopt_omit_version_numbers       1
@@ -1179,12 +1236,52 @@ int isoburn_igopt_get_extensions(struct isoburn_imgen_opts *o, int *ext);
 #define isoburn_igopt_no_j_force_dots         8192
 #define isoburn_igopt_allow_dir_id_ext       16384
 #define isoburn_igopt_joliet_long_names      32768
-#define isoburn_igopt_joliet_rec_mtime      0x8000
-#define isoburn_igopt_iso1999_rec_mtime    0x10000
+#define isoburn_igopt_joliet_rec_mtime     0x10000
+#define isoburn_igopt_iso1999_rec_mtime    0x20000
+#define isoburn_igopt_allow_7bit_ascii     0x40000
 int isoburn_igopt_set_relaxed(struct isoburn_imgen_opts *o, int relax);
 int isoburn_igopt_get_relaxed(struct isoburn_imgen_opts *o, int *relax);
 
 
+/** If not isoburn_igopt_allow_deep_paths is in effect, then it may become
+    necessary to relocate directories so that no ECMA-119 file path
+    has more than 8 components. These directories are grafted into either
+    the root directory of the ISO image or into a dedicated relocation
+    directory. For details see libisofs.h.
+    Wrapper for: iso_write_opts_set_rr_reloc()
+    @since 1.2.2
+    @param o     The option set to work on
+    @param name  The name of the relocation directory in the root directory.
+                 Do not prepend "/". An empty name or NULL will direct
+                 relocated directories into the root directory. This is the
+                 default.
+                 If the given name does not exist in the root directory when
+                 isoburn_disc_write() is called, and if there are directories
+                 at path level 8, then directory /name will be created
+                 automatically.
+    @param flags Bitfield for control purposes.
+                 bit0= Mark the relocation directory by a Rock Ridge RE entry,
+                       if it gets created during isoburn_disc_write(). This
+                       will make it invisible for most Rock Ridge readers.
+                 bit1= not settable via API (used internally)
+    @return      > 0 success, <= 0 failure
+*/
+int isoburn_igopt_set_rr_reloc(struct isoburn_imgen_opts *o, char *name,
+                               int flags);
+
+/** Obtain the settings of isoburn_igopt_set_rr_reloc().
+    @since 1.2.2
+    @param o     The option set to work on
+    @param name  Will return NULL or a pointer to the name of the relocation
+                 directory in the root directory. Do not alter or dispose the
+                 memory which holds this name.
+    @param flags Will return the flags bitfield.
+    @return      > 0 success, <= 0 failure
+*/
+int isoburn_igopt_get_rr_reloc(struct isoburn_imgen_opts *o, char **name,
+                               int *flags);
+
+
 /** Caution: This option breaks any assumptions about names that
              are supported by ECMA-119 specifications.
     Try to omit any translation which would make a file name compliant to the
@@ -1629,6 +1726,14 @@ int isoburn_igopt_get_disc_label(struct isoburn_imgen_opts *opts,
 */
 IsoImage *isoburn_get_attached_image(struct burn_drive *d);
 
+/** Get the start address of the image that is attached to the drive, if any.
+    @since 1.2.2
+    @param d The drive to inquire
+    @return  The logical block address where the System Area of the image
+             starts. <0 means that the address is invalid.
+*/
+int isoburn_get_attached_start_lba(struct burn_drive *d);
+
 
 /** Load the ISO filesystem directory tree from the medium in the given drive.
     This will give libisoburn the base on which it can let libisofs perform
@@ -1667,7 +1772,7 @@ int isoburn_read_image(struct burn_drive *d,
     before it may be removed from memory.
     @since 0.1.0
     @param drive  The drive which will be used with isoburn_read_image()
-                  It has to be aquired by an isoburn_* wrapper call.
+                  It has to be acquired by an isoburn_* wrapper call.
     @param read_pacifier  The callback function
     @param app_handle  The app handle which the callback function can obtain
                        via iso_image_get_attached_data() from its IsoImage*
@@ -1714,6 +1819,17 @@ int isoburn_get_img_partition_offset(struct burn_drive *drive,
 int isoburn_attach_image(struct burn_drive *d, IsoImage *image);
 
 
+/** Set the start address of the image that is attached to the drive, if any.
+    @since 1.2.2
+    @param d    The drive to inquire
+    @param lba  The logical block address where the System Area of the image
+                starts. <0 means that the address is invalid.
+    @param flag Bitfield, submit 0 for now.
+    @return     <=0 error (e.g. because no image is attached), 1 = success
+*/
+int isoburn_attach_start_lba(struct burn_drive *d, int lba, int flag);
+
+
 /** Return the best possible estimation of the currently available capacity of
     the medium. This might depend on particular write option settings and on
     drive state.
@@ -1826,8 +1942,8 @@ int isoburn_prepare_new_image(struct burn_drive *in_drive,
     into some burn program like with this classic gesture:
       mkisofs -M $dev -C $msc1,$nwa | cdrecord -waiti dev=$dev
     Parameter translation into libisoburn:
-      $dev  is the address by which parameter in_drive of this call was aquired
-      $msc1 was set by isoburn_set_msc1() before image reading
+      $dev  is the address by which parameter in_drive of this call was
+            acquired $msc1 was set by isoburn_set_msc1() before image reading
             or was detected from the in_drive medium
       $nwa  is a parameter of this call
             or can be used as detected from the in_drive medium
@@ -1887,7 +2003,7 @@ int isoburn_cancel_prepared_write(struct burn_drive *input_drive,
     Override the truncation setting that was made with flag bit2 during the
     call of isoburn_drive_aquire. This applies only to stdio pseudo drives.
     @since 0.1.6
-    @param drive The drive which was aquired and shall be used for writing.
+    @param drive The drive which was acquired and shall be used for writing.
     @param flag Bitfield controlling the setting:
                 bit0= truncate (else do not truncate)
                 bit1= do not warn if call is inappropriate to drive
@@ -1976,7 +2092,7 @@ int isoburn_sync_after_write(struct burn_drive *input_drive,
                              struct burn_drive *output_drive, int flag);
 
 
-/** Release an aquired drive.
+/** Release an acquired drive.
     Wrapper for: burn_drive_release()
     @since 0.1.0
     @param drive The drive to be released
