@@ -3,7 +3,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2011 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2012 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -122,6 +122,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  for(i=0;i<m->rc_filename_count-1;i++)
    strcpy(m->rc_filenames[i],Xorriso_sys_rc_nameS[i]);
  m->rc_filenames[m->rc_filename_count-1][0]= 0;
+ m->arrange_args= 0;
  m->mkisofsrc_done= 0;
 
  m->wdi[0]= 0;
@@ -143,6 +144,8 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->scdbackup_tag_written[0]= 0;
  m->scdbackup_tag_listname[0]= 0;
  m->relax_compliance= 0;
+ m->rr_reloc_dir[0]= 0;
+ m->rr_reloc_flags= 1;
  m->untranslated_name_len= 0;
  m->do_follow_pattern= 1;
  m->do_follow_param= 0;
@@ -189,6 +192,9 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->displacement_sign= 0;
  m->drives_exclusive= 1;
  m->early_stdio_test= 0;
+ m->cache_num_tiles= 0;
+ m->cache_tile_blocks= 0;
+ m->cache_default= 1 | 2;
  m->do_calm_drive= 1;
  m->indev[0]= 0;
  m->in_drive_handle= NULL;
@@ -196,6 +202,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->in_charset= NULL;
  m->isofs_st_out= time(0) - 1;
  m->indev_is_exclusive= 1;
+ m->indev_off_adr[0]= 0;
  m->isofs_st_in= 0;
  m->volset_change_pending= 0;
  m->no_volset_present= 0;
@@ -207,6 +214,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->out_charset= NULL;
  m->dev_fd_1= -1;
  m->outdev_is_exclusive= 1;
+ m->outdev_off_adr[0]= 0;
  m->grow_blindly_msc2= -1;
  m->ban_stdio_write= 0;
  m->do_dummy= 0;
@@ -270,6 +278,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->do_concat_split= 1;
  m->do_auto_chmod= 0;
  m->do_restore_sort_lba= 0;
+ m->do_strict_acl= 0;
  m->dialog= 0;
  m->bsl_interpretation= 0;
  m->search_mode= 0;
@@ -340,6 +349,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->pacifier_style= 0;
  m->pacifier_interval= 1.0;
  m->pacifier_count= 0;
+ m->pacifier_prev_count= 0;
  m->pacifier_total= 0;
  m->pacifier_byte_count= 0;
  m->pacifier_fifo= NULL;
