@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2010 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2011 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -1212,6 +1212,8 @@ int Xorriso_findx_action(struct XorrisO *xorriso, struct FindjoB *job,
    if(ret != -1)
      ret= Xorriso_estimate_file_size(xorriso, job, basename, stbuf.st_mode,
                                      stbuf.st_size, 0);
+ } else if(action == 44) { /* list_extattr */
+   ret= Xorriso_list_extattr(xorriso, NULL, abs_path, show_path, target, 2);
  } else {
    Text_shellsafe(show_path, xorriso->result_line, 0);
    strcat(xorriso->result_line, "\n");
@@ -1408,12 +1410,12 @@ int Xorriso_restore_sorted(struct XorrisO *xorriso, int count,
      /* sort_lba : Make directories plus node_array and then
                    run array extractor (with eventual hardlink detection)
      */
-     hflag= (1 << 7) | ((!!(flag & 2)) << 9);
+     hflag= (1 << 7) | ((!!(flag & 2)) << 9) | (flag & 32);
      ret= Xorriso_restore(xorriso, src_array[i], tgt_array[i],
                           (off_t) 0, (off_t) 0, hflag);
      if(ret <= 0) {
        (*problem_count)++;
-       hret= Xorriso_eval_problem_status(xorriso, ret, 0);
+       hret= Xorriso_eval_problem_status(xorriso, ret, 1 | 2);
        if(hret < 0)
          goto ex;
      }
@@ -1433,10 +1435,10 @@ int Xorriso_restore_sorted(struct XorrisO *xorriso, int count,
      if(src_array[i] == NULL || tgt_array[i] == NULL)
    continue;
      ret= Xorriso_restore(xorriso, src_array[i], tgt_array[i],
-                          (off_t) 0, (off_t) 0, 2 << 7);
+                          (off_t) 0, (off_t) 0, (2 << 7) | (flag & 32));
      if(ret <= 0) {
        (*problem_count)++;
-       hret= Xorriso_eval_problem_status(xorriso, ret, 0);
+       hret= Xorriso_eval_problem_status(xorriso, ret, 1 | 2);
        if(hret < 0)
          goto ex;
      }
@@ -1453,11 +1455,11 @@ int Xorriso_restore_sorted(struct XorrisO *xorriso, int count,
      if(src_array[i] == NULL || tgt_array[i] == NULL)
    continue;
      ret= Xorriso_restore(xorriso, src_array[i], tgt_array[i],
-                          (off_t) 0, (off_t) 0, 0);
+                          (off_t) 0, (off_t) 0, flag & 32);
      if(ret <= 0) {
        (*problem_count)++;
-       hret= Xorriso_eval_problem_status(xorriso, ret, flag & 32);
-       if(ret < 0)
+       hret= Xorriso_eval_problem_status(xorriso, ret, 1 | 2);
+       if(hret < 0)
          goto ex;
      }
    }
@@ -1665,16 +1667,25 @@ int Xorriso_make_restore_path(struct XorrisO *xorriso,
    ipfx= Xorriso_lst_get_text(s, 0);
    li= strlen(ipfx);
    dpfx= Xorriso_lst_get_text(d, 0);
-   if(strncmp(img_path, ipfx, li) != 0)
+   if(li == 1 && ipfx[0] == '/') {
+     li= 0;
+     if(img_path[0] != '/')
  continue;
-   if(img_path[li] != 0 && img_path[li] != '/')
+   } else {
+     if(strncmp(img_path, ipfx, li) != 0)
  continue;
+     if(img_path[li] != 0 && img_path[li] != '/')
+ continue;
+   }
    if(strlen(dpfx) + strlen(img_path) - li + 1 >= SfileadrL)
      return(-1);
-   if(img_path[li]=='/')
-     sprintf(disk_path, "%s/%s", dpfx, img_path + strlen(ipfx) + 1);
-   else
-     strcpy(disk_path, dpfx);
+   if(img_path[li]=='/') {
+     if(dpfx[0] == '/' && dpfx[1] == 0)
+       sprintf(disk_path, "/%s", img_path + li + 1);
+     else
+       sprintf(disk_path, "%s/%s", dpfx, img_path + li + 1);
+   } else
+     strcpy(disk_path, dpfx);     /* img_path[li] is 0, img_path equals ipfx */
    found_s= s;
    found_d= d;
    if(s != *img_prefixes || !(flag & 1))
