@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2011 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2012 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -293,7 +293,7 @@ int Xorriso_option_print_size(struct XorrisO *xorriso, int flag)
 {
  int ret, fd;
 
- if(!xorriso->volset_change_pending) {
+ if(!Xorriso_change_is_pending(xorriso, 0)) {
    sprintf(xorriso->info_text,"-print_size: No image modifications pending");
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "WARNING", 0);
    if(!(flag & 1)) {
@@ -440,17 +440,6 @@ int Xorriso_option_reassure(struct XorrisO *xorriso, char *mode, int flag)
 }
 
 
-/* Option -unregister_filter */
-int Xorriso_option_unregister_filter(struct XorrisO *xorriso, char *name,
-                                     int flag)
-{
- int ret;
-
- ret= Xorriso_external_filter(xorriso, name, "", "", 0, NULL, 1);
- return(ret);
-}
-
-
 /* Option -report_about */
 int Xorriso_option_report_about(struct XorrisO *xorriso, char *in_severity,
                                 int flag)
@@ -586,7 +575,7 @@ int Xorriso_option_rollback(struct XorrisO *xorriso, int flag)
  char *indev= NULL, *which_will;
 
  Xorriso_alloc_meM(indev, char, SfileadrL);
- if(xorriso->volset_change_pending)
+ if(Xorriso_change_is_pending(xorriso, 0))
    which_will= "revoke the pending image changes";
  else
    which_will= "reload the image";
@@ -647,6 +636,26 @@ unknown_mode:;
 }
 
 
+/* Command -rr_reloc_dir */
+int Xorriso_option_rr_reloc_dir(struct XorrisO *xorriso, char *name, int flag)
+{
+ if(strlen(name) > 255) {
+   sprintf(xorriso->info_text,
+           "Name too long with -rr_reloc_dir. Max. 255 bytes allowed.");
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+   return(0);
+ }
+ if(strchr(name, '/') != NULL) {
+   sprintf(xorriso->info_text,
+           "Name given with -rr_reloc_dir contains '/' character");
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+   return(0);
+ }
+ strcpy(xorriso->rr_reloc_dir, name);
+ return(1);
+}
+
+
 /* Option -scdbackup_tag list_path record_name */
 int Xorriso_option_scdbackup_tag(struct XorrisO *xorriso, char *listname,
                                  char *recname, int flag)
@@ -1498,6 +1507,17 @@ int Xorriso_option_uid(struct XorrisO *xorriso, char *uid, int flag)
 }
 
 
+/* Option -unregister_filter */
+int Xorriso_option_unregister_filter(struct XorrisO *xorriso, char *name,
+                                     int flag)
+{
+ int ret;
+
+ ret= Xorriso_external_filter(xorriso, name, "", "", 0, NULL, 1);
+ return(ret);
+}
+
+
 /* Options -update and -update_r
    @param flag bit0= issue start and summary message
                bit1= do not reset pacifier, no final pacifier message
@@ -1669,7 +1689,7 @@ int Xorriso_option_update(struct XorrisO *xorriso, char *disk_path,
  xorriso->pacifier_interval= mem_pci;
  if(mem_lut!=xorriso->last_update_time && !(flag & (2 | 4)))
    Xorriso_pacifier_callback(xorriso, "content bytes read",
-                             xorriso->pacifier_count, 0, "", 1);
+                             xorriso->pacifier_count, 0, "", 1 | 8 | 32);
 report_outcome:;
  if(ret>0) {
    sprintf(xorriso->info_text,
@@ -1738,7 +1758,7 @@ int Xorriso_option_version(struct XorrisO *xorriso, int flag)
  sprintf(xorriso->result_line,
 "ISO 9660 Rock Ridge filesystem manipulator and CD/DVD/BD burn program\n");
  sprintf(xorriso->result_line+strlen(xorriso->result_line),
-"Copyright (C) 2011, Thomas Schmitt <scdbackup@gmx.net>, libburnia project.\n");
+"Copyright (C) 2012, Thomas Schmitt <scdbackup@gmx.net>, libburnia project.\n");
  Xorriso_result(xorriso, 0);
  sprintf(xorriso->result_line,
          "xorriso version   :  %d.%d.%d%s\n",
