@@ -2,7 +2,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2011 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2012 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -825,6 +825,10 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
    ext|= isoburn_igopt_no_emul_toc;
  isoburn_igopt_set_extensions(sopts, ext);
  isoburn_igopt_set_relaxed(sopts, relax);
+ ret = isoburn_igopt_set_rr_reloc(sopts, xorriso->rr_reloc_dir,
+                                  xorriso->rr_reloc_flags);
+ if(ret <= 0)
+   {ret= 0; goto ex;}
  ret= isoburn_igopt_set_untranslated_name_len(sopts,
                                               xorriso->untranslated_name_len);
  if(ret <= 0)
@@ -1900,6 +1904,9 @@ int Xorriso_burn_track(struct XorrisO *xorriso, off_t write_start_address,
  if(ret<=0) 
    goto ex;
 
+ sprintf(xorriso->info_text, "Beginning to write data track.\n");
+ Xorriso_info(xorriso,0);
+
  /* Important: do not return until burn_is_aborting() was checked */
  signal_mode= 1;
  ret= burn_drive_get_drive_role(drive);
@@ -2061,6 +2068,12 @@ int Xorriso_relax_compliance(struct XorrisO *xorriso, char *mode,
    } else if(l == 14 && strncmp(cpt, "full_ascii_off", l) == 0) {
      xorriso->relax_compliance&= ~isoburn_igopt_allow_full_ascii;
 
+   } else if((l == 10 && strncmp(cpt, "7bit_ascii", l) == 0) ||
+             (l == 13 && strncmp(cpt, "7bit_ascii_on", l) == 0)) {
+     xorriso->relax_compliance|= isoburn_igopt_allow_7bit_ascii;
+   } else if(l == 14 && strncmp(cpt, "7bit_ascii_off", l) == 0) {
+     xorriso->relax_compliance&= ~isoburn_igopt_allow_7bit_ascii;
+
    } else if((l == 17 && strncmp(cpt, "joliet_long_paths", l) == 0) ||
              (l == 20 && strncmp(cpt, "joliet_long_paths_on", l) == 0)) {
      xorriso->relax_compliance|= isoburn_igopt_joliet_longer_paths;
@@ -2081,9 +2094,13 @@ int Xorriso_relax_compliance(struct XorrisO *xorriso, char *mode,
 
    } else if((l ==  9 && strncmp(cpt, "rec_mtime", l) == 0) ||
              (l == 12 && strncmp(cpt, "rec_mtime_on", l) == 0)) {
-     xorriso->relax_compliance|= isoburn_igopt_dir_rec_mtime;
+     xorriso->relax_compliance|= (isoburn_igopt_dir_rec_mtime |
+                                  isoburn_igopt_joliet_rec_mtime |
+                                  isoburn_igopt_iso1999_rec_mtime);
    } else if(l == 13 && strncmp(cpt, "rec_mtime_off", l) == 0) {
-     xorriso->relax_compliance&= ~isoburn_igopt_dir_rec_mtime;
+     xorriso->relax_compliance&= ~(isoburn_igopt_dir_rec_mtime | 
+                                  isoburn_igopt_joliet_rec_mtime |
+                                  isoburn_igopt_iso1999_rec_mtime);
 
    } else if((l ==  6 && strncmp(cpt, "old_rr", l) == 0) ||
              (l ==  9 && strncmp(cpt, "old_rr_on", l) == 0) ||
@@ -2211,6 +2228,8 @@ int Xorriso_get_relax_text(struct XorrisO *xorriso, char mode[1024],
    strcat(mode, ":lowercase");
  if(r & isoburn_igopt_allow_full_ascii)
    strcat(mode, ":full_ascii");
+ else if(r & isoburn_igopt_allow_7bit_ascii)
+   strcat(mode, ":7bit_ascii");
  if(r & isoburn_igopt_joliet_longer_paths)
    strcat(mode, ":joliet_long_paths");
  if(r & isoburn_igopt_joliet_long_names)
@@ -2521,7 +2540,7 @@ int Xorriso_close_damaged(struct XorrisO *xorriso, int flag)
  struct burn_drive *drive;
  struct burn_write_opts *burn_options= NULL;
 
- if(xorriso->volset_change_pending) {
+ if(Xorriso_change_is_pending(xorriso, 0)) {
    sprintf(xorriso->info_text,
            "Image changes pending. -commit or -rollback first");
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
